@@ -224,7 +224,7 @@ gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 	column = gtk_tree_view_column_new ();
 
 	cell = gtk_cell_renderer_pixbuf_new ();
-	pixbuf = gtk_widget_render_icon (dialog->tree_view, GCONF_STOCK_BOOKMARK, GTK_ICON_SIZE_MENU, NULL);
+	pixbuf = gtk_widget_render_icon (dialog->tree_view, STOCK_BOOKMARK, GTK_ICON_SIZE_MENU, NULL);
 	g_object_set (G_OBJECT (cell),
 		      "pixbuf", pixbuf,
 		      NULL);
