@@ -66,8 +66,10 @@ gconf_tree_model_get_tree_path_from_gconf_path (GConfTreeModel *tree_model, cons
 			if (strcmp (tmp_str, key_array[i]) == 0) {
 				found_iter = child_iter;
 				found = TRUE;
+				g_free (tmp_str);
 				break;
-			}
+			} else
+				g_free (tmp_str);
 		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_model), &child_iter));
 
 		if (!found)
